# Oh My Event

> Upon my quest into the mysteries of the Event Camera, a collection of reusable modules and utilities were forged.

This repo contains basic and convenient event processing modules and utilities.
